==> haskell-bower-json-1.1.0.0-221.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-6ZMLmQyn8in3iZPlqhAtq8
key:                  bower-json-1.1.0.0-6ZMLmQyn8in3iZPlqhAtq8
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  918f92b041191c58fe17a44e245f8ca4
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-6ZMLmQyn8in3iZPlqhAtq8
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-better-errors-0.9.1.3-I6N4BBe6LfBEk5gaGiecpe base-4.18.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0 mtl-2.3.1
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.1.0.0-222-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-3iyPw0AF5sjDzJR8Oryskq
key:                  bower-json-1.1.0.0-3iyPw0AF5sjDzJR8Oryskq
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  829af24b0dfdabfa85f3d8afbb6d8577
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-3iyPw0AF5sjDzJR8Oryskq
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-better-errors-0.9.1.3-2uIVkuSZqUl7J3Bw2ULJag base-4.18.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0 mtl-2.3.1
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
